========================
Running with Neuronvisio
========================


To run with neuronvisio the model just launch tha main from an ipython console::

    ipython -pylab
    
    run main.py

Don't forget to compile the mod file first with nrnivmodl. More info online at
http://mattions.github.com/neuronvisio/
